log using hk_replication.txt, text replace
*
* This is replication program (stata 15.1) and data for:
*
* Hoshi, Takeo and Kozo Kiyota (2019) ``Potentials for Inward Foreign Direct Investment in Japan''
*
* Please note that the different version of the software may generate slightly different results from the published version.
*
clear all
set more off
set matsize 11000
set maxvar 30000

use fdi_gravity, clear
drop if iso3_d == iso3_o

**********************************************************************************************************************
* drop outliers
**********************************************************************************************************************

sort pair year
by pair: gen dinstock = (instock - l.instock)/l.instock
sum dinstock, detail
gen     outlier = 0
replace outlier = 1 if dinstock != . & (dinstock < r(p1) | dinstock > r(p99))
table outlier
drop if outlier == 1

**********************************************************************************************************************
* lagged variables
**********************************************************************************************************************
sort pair year
by pair: gen lrta = l.rta
by pair: gen lwto2 = l.wto2
by pair: gen lbit_e = l.bit_e
by pair: gen llpop_o = l.lpop_o
by pair: gen llpop_d = l.lpop_d
by pair: gen llpgdp_o = l.lpgdp_o
by pair: gen llpgdp_d = l.lpgdp_d
by pair: gen lldist = l.ldist
by pair: gen lcomcur = l.comcur
by pair: gen lcomlang_off = l.comlang_off
by pair: gen lcomrelig = l.comrelig
by pair: gen lcolony = l.colony

**********************************************************************************************************************
* dummies
**********************************************************************************************************************

sum year
gen trend = ln(year-1984)
egen dcountry = group(destination) if instock != .
sum dcountry
table iso3_d if OECD_d == 1, c(m dcountry)
tabulate dcountry, generate(dd)
* dd35 = the United States (reference)
forvalue i = 1/34 {
  gen dtrend`i' = trend*dd`i'
  }

* reference country = the United States (dcountry = 35 & origin = 201)

xi, pre(T) i.year
char origin[omit] 201
xi, pre(F_1) i.origin
char dcountry[omit] 35
xi, pre(F_2) i.dcountry


**********************************************************************************************************************
* Table A1
**********************************************************************************************************************

table year iso3_d if OECD_d == 1, c(sum instock) m format(%12.0f)

**********************************************************************************************************************
* Table A2
**********************************************************************************************************************

table year iso3_d if OECD_d == 1, c(m gdp_d) m format(%15.0f)

**********************************************************************************************************************
* Table A3
**********************************************************************************************************************

table year iso3_d if OECD_d == 1, c(sum inflow) m format(%15.0f)

**********************************************************************************************************************
* Table 1 <= calculate from Tables A1 and A2 above
**********************************************************************************************************************

**********************************************************************************************************************
* OLS
**********************************************************************************************************************

* change reference = the United States (dcountry = 35 & origin = 201)
char dcountry[omit] 35
char origin[omit] 201

xi: regress lninstock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony i.origin i.dcountry trend dtrend* if year < 2013, cluster(pair)
estimates store odfixed2012
predict ols2012, xb

**********************************************************************************************************************
* Table 3
**********************************************************************************************************************
*
* column (2)
*
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* if year < 2013, cluster(pair)
estimates store notrend2012
predict notrend2012
gen fit2 = notrend2012^2
gen sample = e(sample)
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* fit2 if year < 2013, cluster(pair)
drop fit2
*
* column (1)
*
poisson instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony if sample == 1 & year < 2013, cluster(pair)
estimates store traditional2012
predict traditional2012
gen fit2 = traditional^2
poisson instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony fit2 if sample == 1 & year < 2013, cluster(pair) difficult
drop fit2 sample
*
* column (3)
*
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if year < 2013, cluster(pair)
estimates store odfixed2012
predict odfixed2012
   ***********************************************************************************************************************
   * Table 2
   ***********************************************************************************************************************
tabstat instock if e(sample) == 1, s(n mean sd p25 p50 p75) format(%18.1fc) columns(statistics)
tabstat rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony if e(sample) == 1,  s(n mean sd p25 p50 p75) columns(statistics)
*
* column (3)
*
gen fit2 = odfixed2012^2
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* fit2 if year < 2013, cluster(pair)
drop fit2

**********************************************************************************************************************
* Figure 2, data
**********************************************************************************************************************

ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if year < 2008, cluster(pair)
predict odfixed2007

table year if iso3_d == "JPN", c(sum instock sum odfixed2012 sum odfixed2007) m format(%15.0f)

**********************************************************************************************************************
* Table 8
**********************************************************************************************************************
*
* column (1)
*
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony db_start_d F_* trend dtrend*, cluster(pair)
predict wbdob_start
gen fit2 = wbdob_start^2
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony db_start_d F_* trend dtrend* fit2, cluster(pair)
drop fit2
*
* column (2)
*
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony db_tax_d F_* trend dtrend*, cluster(pair)
predict wbdob_tax
gen fit2 = wbdob_tax^2
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony db_tax_d F_* trend dtrend* fit2, cluster(pair)
drop fit2
*
* column (3)
*
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony db_contract_d F_* trend dtrend*, cluster(pair)
predict wbdob_contract
gen fit2 = wbdob_contract^2
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony db_contract_d F_* trend dtrend* fit2, cluster(pair)
drop fit2
*
* column (4)
*
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony db_start_d db_tax_d db_contract_d F_* trend dtrend*, cluster(pair)
predict wbdob
gen fit2 = wbdob^2
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony db_start_d db_tax_d db_contract_d F_* trend dtrend* fit2, cluster(pair)
drop fit2
*
* column (5)
*
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony db_overall_d F_* trend dtrend*, cluster(pair)
predict wbdob_overall
gen fit2 = wbdob_overall^2
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony db_overall_d F_* trend dtrend* fit2, cluster(pair)
drop fit2

**********************************************************************************************************************
* Table 6
**********************************************************************************************************************
*
* column (1)
*
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* if year < 2013 & inflow >= 0, cluster(pair)
estimates store flowmr2012
predict flowmr2012
gen fit2 = flowmr2012^2
gen sample = e(sample)
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* fit2 if year < 2013 & inflow >= 0, cluster(pair)
drop fit2
*
* column (2)
*
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony if sample == 1 & year < 2013 & inflow >= 0, cluster(pair)
estimates store flowtra2012
predict flowtra2012
gen fit2 = flowtra2012^2
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* fit2 if sample == 1 & year < 2013 & inflow >= 0, cluster(pair)
drop fit2 sample
*
* column (3)
*
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if year < 2013 & inflow >= 0, cluster(pair)
estimates store flow2012
predict flow2012
gen fit2 = flow2012^2
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* fit2 if year < 2013 & inflow >= 0, cluster(pair)
drop fit2

**********************************************************************************************************************
* Figure 7, data
**********************************************************************************************************************

ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if year < 2008 & inflow >= 0, cluster(pair)
predict flow2007

table year if iso3_d == "JPN", c(sum inflow sum flow2012 sum flow2007) m format(%15.0f)

**********************************************************************************************************************
* Table 7
**********************************************************************************************************************
*
* column (2)
*
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* if year < 2013, cluster(pair)
estimates store lagmr2012
predict lagmr2012
gen fit2 = lagmr2012^2
gen sample = e(sample)

ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* fit2 if year < 2013, cluster(pair)
drop fit2
*
* column (1)
*
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony if sample == 1 & year < 2013, cluster(pair)
estimates store lagtra2012
predict lagtra2012
gen fit2 = lagtra2012^2
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony fit2 if sample == 1 & year < 2013, cluster(pair)
drop fit2 sample
*
* column (3)
*
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend* if year < 2013, cluster(pair)
estimates store lag2012
predict lag2012
gen fit2 = lag2012^2
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend* fit2 if year < 2013, cluster(pair)
drop fit2

**********************************************************************************************************************
* Figure 8, data
**********************************************************************************************************************

ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend* if year < 2008, cluster(pair)
predict lag2007

table year if iso3_d == "JPN", c(sum instock sum lag2012 sum lag2007) m format(%15.0f)

**********************************************************************************************************************
* Table 3 <= coefficients are obtained from the regression results above (Table 2, column (3))
**********************************************************************************************************************

**********************************************************************************************************************
* Tables 3, HPC tests
**********************************************************************************************************************

hpc instock rta wto2 bit_e ldist comcur comlang_off comrelig colony if year < 2013 & instock != ., a(ols2012) b(odfixed2012) cluster(pair)
hpc instock rta wto2 bit_e ldist comcur comlang_off comrelig colony if year < 2013 & instock != ., a(traditional2012) b(odfixed2012) cluster(pair)
hpc instock rta wto2 bit_e ldist comcur comlang_off comrelig colony if year < 2013 & instock != ., a(notrend2012) b(odfixed2012) cluster(pair)
hpc instock rta wto2 bit_e ldist comcur comlang_off comrelig colony if year < 2013 & instock != ., a(traditional2012) b(notrend2012) cluster(pair)

**********************************************************************************************************************
* Tables 6, HPC tests
**********************************************************************************************************************

hpc inflow rta wto2 bit_e ldist comcur comlang_off comrelig colony if year < 2013 & inflow != . & inflow >= 0, a(flowtra2012) b(flow2012) cluster(pair)
hpc inflow rta wto2 bit_e ldist comcur comlang_off comrelig colony if year < 2013 & inflow != . & inflow >= 0, a(flowmr2012) b(flow2012) cluster(pair)
hpc inflow rta wto2 bit_e ldist comcur comlang_off comrelig colony if year < 2013 & inflow != . & inflow >= 0, a(flowtra2012) b(flowmr2012) cluster(pair)

**********************************************************************************************************************
* Tables 7, HPC tests
**********************************************************************************************************************

hpc instock lrta lwto2 lbit_e lldist lcomcur lcomlang_off lcomrelig lcolony if year < 2013 & instock != ., a(lagtra2012) b(lag2012) cluster(pair)
hpc instock lrta lwto2 lbit_e lldist lcomcur lcomlang_off lcomrelig lcolony if year < 2013 & instock != ., a(lagmr2012) b(lag2012) cluster(pair)
hpc instock lrta lwto2 lbit_e lldist lcomcur lcomlang_off lcomrelig lcolony if year < 2013 & instock != ., a(lagtra2012) b(lagmr2012) cluster(pair)

**********************************************************************************************************************
* Figure 3, data
**********************************************************************************************************************

preserve
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if year < 2008, cluster(pair)
* do not converge
*ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if year < 2009, cluster(pair)
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if year < 2010, cluster(pair)
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if year < 2011, cluster(pair)
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if year < 2012, cluster(pair)
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if year < 2013, cluster(pair)
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if year < 2014, cluster(pair)
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if year < 2015, cluster(pair)
ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend*, cluster(pair)
gen constJPN = _b[F_2dcountry_21]*F_2dcountry_21
gen trendJPN = _b[dtrend21]*dtrend21

ppml instock rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if iso3_d != "JPN", cluster(pair)
predict finstock
rename finstock finstockUS
gen finstockJP = finstockUS*exp(- _b[trend]*trend + trendJPN)
gen finstock0 = finstockUS*exp(- _b[trend]*trend)
keep if iso3_d == "JPN"
gen case = 1
table year, c(sum instock sum finstock0 sum finstockUS sum finstockJP) format(%18.3f)

**********************************************************************************************************************
* Table 5, data
**********************************************************************************************************************

keep if iso3_o == "USA" | iso3_o == "NLD" | iso3_o == "FRA" | iso3_o == "GBR" | iso3_o == "SGP" | iso3_o == "CHE"
table case if finstock0 != ., c(sum instock sum finstock0 m finstockUS m finstockJP) format(%18.3f)
table year, c(sum instock sum finstock0 sum finstockUS sum finstockJP) format(%18.3f)
table year iso3_o, c(sum instock) format(%18.3f)
table year iso3_o, c(sum finstock0) format(%18.3f)
table year iso3_o, c(sum finstockUS) format(%18.3f)
table year iso3_o, c(sum finstockJP) format(%18.3f)
table year, c(m gdp_d sd gdp_d) format(%18.3f)

restore

**********************************************************************************************************************
* Figure 7, data
**********************************************************************************************************************

preserve
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if inflow >= 0 & year < 2008, cluster(pair)
* do not converge
*ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if inflow >= 0 & year < 2009, cluster(pair)
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if inflow >= 0 & year < 2010, cluster(pair)
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if inflow >= 0 & year < 2011, cluster(pair)
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if inflow >= 0 & year < 2012, cluster(pair)
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if inflow >= 0 & year < 2013, cluster(pair)
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if inflow >= 0 & year < 2014, cluster(pair)
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if inflow >= 0 & year < 2015, cluster(pair)
ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if inflow >= 0, cluster(pair)
gen constJPN = _b[F_2dcountry_21]*F_2dcountry_21
gen trendJPN = _b[dtrend21]*dtrend21

ppml inflow rta wto2 bit_e lpop_o lpgdp_o lpop_d lpgdp_d ldist comcur comlang_off comrelig colony F_* trend dtrend* if iso3_d != "JPN" & inflow >= 0, cluster(pair)

predict finflow
rename finflow finflowUS
gen finflowJP = finflowUS*exp(- _b[trend]*trend + trendJPN)
gen finflow0 = finflowUS*exp(- _b[trend]*trend)
keep if iso3_d == "JPN"
gen case = 1
table year, c(sum inflow sum finflow0 sum finflowUS sum finflowJP) format(%18.3f)

restore

**********************************************************************************************************************
* Figure 8, data
**********************************************************************************************************************

preserve
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend* if year < 2008, cluster(pair)
* do not converge
*ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend* if year < 2009, cluster(pair)
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend* if year < 2010, cluster(pair)
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend* if year < 2011, cluster(pair)
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend* if year < 2012, cluster(pair)
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend* if year < 2013, cluster(pair)
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend* if year < 2014, cluster(pair)
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend* if year < 2015, cluster(pair)
ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend*, cluster(pair)
gen constJPN = _b[F_2dcountry_21]*F_2dcountry_21
gen trendJPN = _b[dtrend21]*dtrend21

ppml instock lrta lwto2 lbit_e llpop_o llpgdp_o llpop_d llpgdp_d lldist lcomcur lcomlang_off lcomrelig lcolony F_* trend dtrend* if iso3_d != "JPN", cluster(pair)

predict finstock
rename finstock finstockUS
gen finstockJP = finstockUS*exp(- _b[trend]*trend + trendJPN)
gen finstock0 = finstockUS*exp(- _b[trend]*trend)
keep if iso3_d == "JPN"
gen case = 1
table year, c(sum instock sum finstock0 sum finstockUS sum finstockJP) format(%18.3f)
restore

log close
